@@ -3,7 +3,7 @@
 package common_data;
 use base qw(Exporter);
 @EXPORT=qw(%known_archs %known_sections %known_non_us_parts %known_archive_parts
-           %known_prios %known_source_fields %known_binary_fields
+           %known_prios %known_source_fields %known_binary_fields %known_udeb_fields
 	   %known_obsolete_fields %known_essential %known_build_essential
 	   %known_obsolete_packages %known_virtual_packages
 	   %known_libstdcs %known_tcls %known_tclxs %known_tks %known_tkxs
@@ -36,7 +36,7 @@ use base qw(Exporter);
     ('source', 'version', 'maintainer', 'binary', 'architecture',
      'standards-version', 'files', 'build-depends', 'build-depends-indep',
      'build-conflicts', 'build-conflicts-indep', 'format', 'origin',
-     'uploaders', 'bugs' );
+     'uploaders' );
 
 %known_binary_fields = map { $_ => 1 }
     ('package', 'version', 'architecture', 'depends', 'pre-depends',
@@ -44,6 +44,12 @@ use base qw(Exporter);
      'replaces', 'essential', 'maintainer', 'section', 'priority',
      'source', 'description', 'installed-size');
 
+%known_udeb_fields = map { $_ => 1 }
+    ('package', 'version', 'architecture', 'subarchitecture', 'depends',
+     'recommends', 'enhances', 'provides', 'installer-menu-item',
+     'replaces', 'maintainer', 'section', 'priority',
+     'source', 'description', 'installed-size');
+
 %known_obsolete_fields = map { $_ => 1 }
     ('revision', 'package-revision', 'package_revision',
      'recommended', 'optional', 'class');
